/*

  Copyright (c) 1999-2000 Yisrael Hersch - All rights reserved.

  "Hayom" is a very simple sample application demonstrating the proper
  usage of the KDATE Hebrew/Civil date conversion DLL. You may use this
  sample application as you see fit.

  No warranties are expressed or implied in the use of KDATE. However
  the underlying code has been extensively tested and is the date
  conversion "engine" used in Kaluach - an easy to use Hebrew/Civil
  calendar for Microsoft Windows.

  The demo version of the KDATE date coversion DLL works for the
  civil years 1993 through 2003. A license for the unlimited version
  of the KDATE DLL (good for the civil years 1 and above) is available
  for $50 (fifty U.S. dollars). Upon receipt of check or money order,
  the unlimited version will be sent by email or by post.

  Yisrael Hersch
  Havradim 11
  Ginot Shomron
  Israel 44853

  Kaluach web page: http://www.kaluach.org
  Mirror: http://kaluach.tripod.com
  Email: contact@kaluach.org

*/


#include <windows.h>

#include "resource.h"
#include "kdate.h"

char *strHebMonths[] = {
	"",
	"Tishrei",
	"Cheshvan",
	"Kislev",
	"Tevet",
	"Shevat",
	"Adar I",
	"Adar II",
	"Nisan",
	"Iyar",
	"Sivan",
	"Tammuz",
	"Av",
	"Elul",
	"Adar",
};

char *strCivMonths[] = {
	"",
	"January",
	"February",
	"March",
	"April",
	"May",
	"June",
	"July",
	"August",
	"September",
	"October",
	"November",
	"December",
};

char *weekday[] = {
	"",
	"Sunday",
	"Monday",
	"Tuesday",
	"Wednesday",
	"Thursday",
	"Friday",
	"Saturday - Shabbat",
};

char *parsha[] = {
	"",
	"B'reshit",       
	"Noach",          
	"Lech L'cha",     
	"Vayera",         
	"Chayei Sarah",   
	"Toldot",         
	"Vayetze",        
	"Vayishlach",     
	"Vayeshev",       
	"Miketz",         
	"Vayigash",       
	"Vayechi",        
	"Sh'mot",         
	"Va'era",         
	"Bo",             
	"B'shalach",      
	"Yitro",          
	"Mishpatim",      
	"T'ruma",         
	"Tetzave",        
	"Ki Tisa",        
	"Vayakhel",       
	"Pekudei",        
	"Vayikra",        
	"Tzav",           
	"Sh'mini",        
	"Tazria",         
	"M'tzora",        
	"Acharei Mot",    
	"K'doshim",       
	"Emor",           
	"Behar",          
	"B'chukotai",     
	"Bamidbar",       
	"Naso",           
	"B'ha'alotcha",   
	"Sh'lach L'chah", 
	"Korach",         
	"Chukat",         
	"Balak",          
	"Pinchas",        
	"Matot",          
	"Mase'ei",        
	"D'varim",        
	"Va'etchanan",    
	"Ekev",           
	"Re'e",           
	"Shoftim",        
	"Ki Tetze",       
	"Ki Tavo",        
	"Nitzavim",       
	"Vayelech",       
	"Ha'azinu",       
	"V'zot Habracha",
};

char *specialShabbat[] = {
	"",
	"Shabbat Shuva",     
	"Shabbat Shira",     
	"Parshat Shekalim",  
	"Parshat Zachor",    
	"Shabbat Hachodesh", 
	"Parshat Parah",     
	"Shabbat Hagadol",   
	"Shabbat Chazon",    
	"Shabbat Nachamu",
	"Shabbat Selichot (Sephardim)",
	"Shabbat Selichot (Ashkenazim)",
};

char *strMoed[] = {
	"",
	"Rosh Hashanah I",
	"Rosh Hashanah II",
	"Fast of Gedaliah",
	"Fast of Gedaliah",
	"Fast of Gedaliah",
	"Erev Yom Kippur", 
	"Yom Kippur",
	"Erev Succot",
	"Succot",	 
	"Succot I",	 
	"Succot II", 
	"Intermediate 1",
	"Intermediate 2",
	"Intermediate 3",
	"Intermediate 4",
	"Intermediate 5",
	"Hoshanah Rabah",
	"Shmini Atzeret",
	"Isru Chag",	 
	"Shmini Atzeret",
	"Simchat Torah", 
	"Isru Chag",	 
	"Taanit BH\"B",	 
	"Taanit BH\"B",	 
	"Taanit BH\"B",	 
	"Taanit BH\"B",	 
	"Ask for rain",	
	"Prayer for drought",
	"Chanukah 1",	 	 
	"Chanukah 2",	 
	"Chanukah 3",	 
	"Chanukah 4",	 
	"Chanukah 5",	 
	"Chanukah 6",	 
	"Chanukah 7",	 
	"Chanukah 8",	 
	"Fast of Tevet", 
	"Tu B'Shevat",	 
	"Purim Katan",	 
	"Shushan P. Katan",
	"Moses died",	 
	"Fast of Esther",
	"Move up fast",	 
	"Fast of Esther",
	"Purim",	 
	"Shushan Purim",
	"Erev Pesach",	
	"Erev Pesach",	
	"Fast of first born",
	"Fast of first born",
	"Pesach",	
	"Pesach I",	
	"Pesach II",
	"Intermediate 1", 
	"Intermediate 2", 
	"Intermediate 3", 
	"Intermediate 4", 
	"Intermediate 5", 
	"Shvii Pesach",	 
	"Isru Chag",	 
	"Shvii Pesach I",
	"Shvii Pesach II",
	"Isru Chag",	 
	"Holocaust Day", 
	"Memorial Day",	 
	"Independence",	 
	"Pesach Sheni",	 
	"Lag B'Omer",	 
	"Jerusalem Day", 
	"Erev Shavuot",	 
	"Shavuot",	 
	"Isru Chag", 
	"Shavuot I", 
	"Shavuot II",
	"Isru Chag", 
	"Fast of Tammuz",  
	"Fast deferred",
	"Fast of Tammuz",  
	"Temple destroyed",
	"Tisha B'Av",	
	"Fast Deferred",
	"Fast of Tisha B'Av",
	"Tu B'Av",	
	"World created",
	"Erev R. Hashanah",
	"Rosh Chodesh",	 
	"Rosh Chodesh (first day)",
	"Rosh Chodesh (second day)",
	"Day %d of the Omer",
};


BOOL WINAPI MainDialog(HWND hDlg, WORD msg, WORD wParam, LONG lParam);

HINSTANCE	hInst;
HWND		MainWin;

CDATE_T		cdate;
HDATE_T		hdate;


/*****************************************************************************
 * Start with today's date. We'll do this one the hard way.
 ****************************************************************************/
void InitDisplay(HWND hDlg) {

	char	str[200];

	// First, we'll display today's civil date...
	// the hard way in order to demonstrate the KDATE API.

	// 1) Get today's civil date
	cdate = GetTodayCivil();

	// 2) Now, even though we can get today's Hebrew date
	//    with a call to a routine, we'll convert the Hebrew
	//    date to the civil date to demonstrate the 
	//    HebrewToCivil function.
	hdate = CivilToHebrew(cdate.day, cdate.month, cdate.year);

	// 3) That's it, we now have today's Hebrew date.
	//    Let's display it.
	wsprintf(str, "%d %s %d", hdate.day, strHebMonths[hdate.month], hdate.year);
	SendDlgItemMessage( hDlg, ID_HEB, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

	// 4) This all could have been done the easy way...
	//      hdate = GetTodayHebrew();
	//      wsprintf(str, "%d %s %d", hdate.day, strHebMonths[hdate.month], hdate.year);
	//      SendDlgItemMessage( hDlg, ID_HEB, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );


	// OK, now let's display today's Hebrew date...
	// the hard way of course :-)

	// 1) Get today's Hebrew date
	hdate = GetTodayHebrew();

	// 2) Now, even though we can get today's Hebrew date
	//    with a call to a routine, we'll convert the Hebrew
	//    date to the civil date to demonstrate the 
	//    HebrewToCivil function.
	cdate = HebrewToCivil(hdate.day, hdate.month, hdate.year);

	// 3) That's it, we now have today's civil date.
	//    Let's display it.
	wsprintf(str, "%d %s %d", cdate.day, strCivMonths[cdate.month], cdate.year);
	SendDlgItemMessage( hDlg, ID_CIV, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

	// 4) This all could have been done the easy way...
	//      CDATE_T cdate = GetTodayCivil();
	//      wsprintf(str, "%d %d %d", cdate.day, cdate.month, cdate.year);
	//      SendDlgItemMessage( hDlg, ID_CIV, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

	// 5) Now how about showing other information
	PARSHA_T p;
	p = GetParsha(hdate, 0);

	if(p.parsha1) {

		// get parsha strings
		if(p.parsha2)
			// double parsha
			wsprintf(str, "Shabbat - Parshiot %s %s", parsha[p.parsha1], parsha[p.parsha2]);
		else
			// regular (single) parsha
			wsprintf(str, "Shabbat - Parshat %s", parsha[p.parsha1]);
		SendDlgItemMessage( hDlg, ID_PARSHA, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

		// get special shabbat strings
		if(p.special) {
			wsprintf(str, "%s", specialShabbat[p.special]);
			SendDlgItemMessage( hDlg, ID_SPECIAL, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
		}
	}
	else {
		int dow;
		dow = HebrewDOW(hdate.day, hdate.month, hdate.year);
		wsprintf(str, "%s", weekday[dow]);
		SendDlgItemMessage( hDlg, ID_PARSHA, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
	}

	MOED_T	moadim[8];
	int		numMoadim;

	numMoadim = GetMoadim(cdate.day, cdate.month, cdate.year, 0, &moadim[0]);
	if(numMoadim) {
		// we'll just get the first one for our demo
		if(moadim[0].moed != SFIRA) {	// don't bother with sfira
			wsprintf(str, "%s", strMoed[moadim[0].moed]);
			SendDlgItemMessage( hDlg, ID_MOED, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
		}
	}

}


/*****************************************************************************
 * Redisplay if NEXT or PREV clicked.
 ****************************************************************************/
void DisplayDate(HWND hDlg) {

	char	str[200];

	// display civil date
	wsprintf(str, "%d %s %d", cdate.day, strCivMonths[cdate.month], cdate.year);
	SendDlgItemMessage( hDlg, ID_CIV, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

	// convert civil date to Hebrew date and display
	hdate = CivilToHebrew(cdate.day, cdate.month, cdate.year);
	wsprintf(str, "%d %s %d", hdate.day, strHebMonths[hdate.month], hdate.year);
	SendDlgItemMessage( hDlg, ID_HEB, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

	// now show other information

	PARSHA_T p;
	p = GetParsha(hdate, 0);

	SendDlgItemMessage( hDlg, ID_SPECIAL, WM_SETTEXT, 0, (LPARAM)(LPSTR)"" );
	if(p.parsha1) {

		// get parsha strings
		if(p.parsha2)
			// double parsha
			wsprintf(str, "Shabbat - Parshiot %s %s", parsha[p.parsha1], parsha[p.parsha2]);
		else
			// regular (single) parsha
			wsprintf(str, "Shabbat - Parshat %s", parsha[p.parsha1]);
		SendDlgItemMessage( hDlg, ID_PARSHA, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );

		// get special shabbat strings
		if(p.special) {
			wsprintf(str, "%s", specialShabbat[p.special]);
			SendDlgItemMessage( hDlg, ID_SPECIAL, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
		}
	}
	else {
		int dow;
		dow = HebrewDOW(hdate.day, hdate.month, hdate.year);
		wsprintf(str, "%s", weekday[dow]);
		SendDlgItemMessage( hDlg, ID_PARSHA, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
	}

	MOED_T	moadim[8];
	int		numMoadim;

	numMoadim = GetMoadim(cdate.day, cdate.month, cdate.year, 0, &moadim[0]);
	if(numMoadim) {
		// we'll just get the first one for our demo
		if(moadim[0].moed != SFIRA) {	// don't bother with sfira
			wsprintf(str, "%s", strMoed[moadim[0].moed]);
			SendDlgItemMessage( hDlg, ID_MOED, WM_SETTEXT, 0, (LPARAM)(LPSTR)str );
		}
		else
			SendDlgItemMessage( hDlg, ID_MOED, WM_SETTEXT, 0, (LPARAM)(LPSTR)"" );
	}
	else
		SendDlgItemMessage( hDlg, ID_MOED, WM_SETTEXT, 0, (LPARAM)(LPSTR)"" );


}


/*****************************************************************************
 * Main Dialog to handle user interface
 ****************************************************************************/
BOOL WINAPI MainDialog(HWND hDlg, WORD msg, WORD wParam, LONG lParam) {

	static KDATE date;

	switch (msg) {
	case WM_INITDIALOG:
		InitDisplay(hDlg);
		break;

	case WM_COMMAND:
		switch( wParam ) {			
		case ID_NEXT:
			cdate = NextDay(cdate.day, cdate.month, cdate.year);
			DisplayDate(hDlg);
			break;
		case ID_PREV:
			cdate = PrevDay(cdate.day, cdate.month, cdate.year);
			DisplayDate(hDlg);
			break;
		case IDOK:
			EndDialog( hDlg, FALSE );
			break;
		default:
			break;
		}
		break;
	}

	return (FALSE);

}


/*****************************************************************************
 * Initial Entry
 *
 * establish a message queue
 * get the instance handle
 * start the user dialog
 ****************************************************************************/
int WINAPI WinMain( HINSTANCE hInstance, HINSTANCE hPrev, LPSTR lpCmd, int nShow ) {

	SetMessageQueue( 100 );
	hInst = hInstance;
	DialogBox( hInstance, MAKEINTRESOURCE( ID_MAIN_SCREEN ), NULL, (DLGPROC)MainDialog ); 
	return( FALSE );

}

  
// ********************************************************************
// END OF FILE
// ********************************************************************
