/*

  KDATE.DLL - version 6
  Copyright (c) 1999-2000 Yisrael Hersch - All rights reserved.

  No warranties are expressed or implied in the use of KDATE. However
  the underlying code has been extensively tested and is the date
  conversion "engine" used in Kaluach - an easy to use Hebrew/Civil
  calendar for Microsoft Windows.

  The demo version of the KDATE date coversion DLL works for the
  civil years 1993 through 2003. A license for the unlimited version
  of the KDATE DLL (good for the civil years 1 and above) is available
  for $50 (fifty U.S. dollars). Upon receipt of check or money order,
  the unlimited version will be sent by email or by post.

  Yisrael Hersch
  Havradim 11
  Ginot Shomron
  Israel 44853

  Kaluach web page: http://www.kaluach.org
  Mirror: http://kaluach.tripod.com
  Email: contact@kaluach.org

*/



// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the KDATE_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// KDATE_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.
#ifdef KDATE_EXPORTS
#define KDATE_API __declspec(dllexport)
#else
#define KDATE_API __declspec(dllimport)
#endif


#ifndef _KDATE_DEFS
#define _KDATE_DEFS


#define TISHREI		1
#define HESHVAN		2
#define KISLEV		3
#define TEVET		4
#define SHEVAT		5
#define ADARI		6
#define ADARII		7
#define NISAN		8
#define IYYAR		9
#define SIVAN		10
#define TAMMUZ		11
#define AV			12
#define ELUL		13
#define ADAR		14

#define JANUARY		1
#define FEBRUARY	2
#define MARCH		3
#define APRIL		4
#define MAY			5
#define JUNE		6
#define JULY		7
#define AUGUST		8
#define SEPTEMBER	9
#define OCTOBER		10
#define NOVEMBER	11
#define DECEMBER	12

#define	SUN		1
#define	MON		2
#define	TUES	3
#define	WED		4
#define	THURS	5
#define	FRI		6
#define	SAT		7

// "special" shabbats
#define  SHABBAT_TSHUVA      1
#define  SHABBAT_SHIRA       2
#define  PARSHAT_SHEKALIM    3
#define  PARSHAT_ZACHOR      4
#define  PARSHAT_HACHODESH   5
#define  PARSHAT_PARAH       6
#define  SHABBAT_HAGADOL     7
#define  SHABBAT_CHAZON      8
#define  SHABBAT_NACHAMU     9
#define  SELICHOT_SEPHARDIM  10
#define  SELICHOT_ASHKENAZIM 11

#endif


#ifndef _KMOED_T
#define _KMOED_T


typedef enum {
	NONE,
	ROSH_HASHANAH_I,
	ROSH_HASHANAH_II,
	TAANIT_GEDALIAH,
	TAANIT_GEDALIAH_SHABBAT,
	TAANIT_GEDALIAH_NIDCHIT,
	EREV_YOM_KIPPUR,
	YOM_KIPPUR,
	EREV_SUCCOT,
	CHAG_SUCCOT,
	CHAG_SUCCOT_I,
	CHAG_SUCCOT_II,
	SUCCOT_1,
	SUCCOT_2,
	SUCCOT_3,
	SUCCOT_4,
	SUCCOT_5,
	HOSHANAH_RABAH,
	SHMINI_ATZERET_SIMCHAT_TORAH,
	ISRU_SHMINI_ATZERET,
	SHMINI_ATZERET,
	SIMCHAT_TORAH,
	ISRU_SIMCHAT_TORAH,
	TAANIT_BHB2FIRST,
	TAANIT_BHB5,
	TAANIT_BHB2LAST,
	TAANIT_BHB2TANINA,
	GESHAMIM,
	BETZORET,
	CHANUKAH_1,
	CHANUKAH_2,
	CHANUKAH_3,
	CHANUKAH_4,
	CHANUKAH_5,
	CHANUKAH_6,
	CHANUKAH_7,
	CHANUKAH_8,
	TZOM_TEVET,
	TU_BSHEVAT,
	PURIM_KATAN,
	SHUSHAN_PURIM_KATAN,
	MOSHE_RABENU,
	TAANIT_ESTHER,
	TAANIT_ESTHER_SHABBAT,
	TAANIT_ESTHER_MUKDAM,
	PURIM,
	SHUSHAN_PURIM,
	EREV_PESACH,
	EREV_PESACH_SHABBAT,
	TAANIT_BECHOROT,
	TAANIT_BECHOROT_MUKDAM,
	CHAG_PESACH,
	CHAG_PESACH_I,
	CHAG_PESACH_II,
	PESACH_1,
	PESACH_2,
	PESACH_3,
	PESACH_4,
	PESACH_5,
	SHVII_PESACH,
	ISRU_SHVIIPESACH,
	SHVII_PESACH_I,
	SHVII_PESACH_II,
	ISRU_SHVIIPESACH_II,
	YOM_HASHOAH,
	YOM_HAZIKARON,
	YOM_HAATZMAUT,
	PESACH_SHENI,
	LAG_BOMER,
	YOM_YERUSHALYIM,
	EREV_SHAVUOT,
	SHAVUOT,
	ISRU_SHAVUOT,
	SHAVUOT_I,
	SHAVUOT_II,
	ISRU_SHAVUOT_II,
	TZOM_TAMMUZ,
	TZOM_TAMMUZ_SHABBAT,
	TZOM_TAMMUZ_NIDCHIT,
	TISHA_BAV_FIRST,
	TISHA_BAV,
	TISHA_BAV_SHABBAT,
	TISHA_BAV_NIDCHIT,
	TU_BAV,
	WORLD_CREATED,
	EREV_ROSH_HASHANAH,
	ROSH_CHODESH,
	ROSH_CHODESH_ALEF,
	ROSH_CHODESH_BET,
	SFIRA,
} HOLIDAY_TYPE;

#endif


#ifndef _DATE_T
#define _DATE_T

typedef struct hdate_t {
	WORD	day;
	WORD	month;
	WORD	year;
} HDATE_T;

typedef struct cdate_t {
	WORD	day;
	WORD	month;
	WORD	year;
} CDATE_T;

#endif

#ifndef _PARSHA_T
#define _PARSHA_T

typedef struct parsha_t {
	int		parsha1;
	int		parsha2;
	int		special;
} PARSHA_T;

#endif

typedef struct moed_t {
	int	moed;
	int	type;
} MOED_T;

typedef void * KDATE;

#ifdef __cplusplus
extern "C" {
#endif

KDATE_API int		HebrewDOW(int day, int month, int year);
KDATE_API HDATE_T	CivilToHebrew(int day, int month, int year);
KDATE_API CDATE_T	HebrewToCivil(int day, int month, int year);
KDATE_API HDATE_T	GetTodayHebrew();
KDATE_API CDATE_T	GetTodayCivil();
KDATE_API CDATE_T	NextDay(int day, int month, int year);
KDATE_API CDATE_T	PrevDay(int day, int month, int year);
KDATE_API PARSHA_T	GetParsha(HDATE_T hd, int diaspora);
KDATE_API int		GetMoadim(int day, int month, int year, int diaspora, MOED_T *moadim);

#ifdef __cplusplus
}
#endif
